@@ -31,6 +31,8 @@ signals:
     void finishSignal();
     void removeSignal();
     void popSignal();
+    void ClipboardHideSignal();
+    void CLipBoardEditSignal();
 public slots:
 };
 #endif // SIDEBARCLIPBOARDSIGNAL_H
