@@ -21,13 +21,20 @@
 #define CLIPBOARDWIDGETENTRY_H
 #include <QWidget>
 #include <QPushButton>
+#include <QLineEdit>
 #include <QLabel>
 #include <QHBoxLayout>
 #include <QIcon>
-#define  EDIT_SVG_PATH  ":/image/edit.svg"
+#include <QLine>
+#include <QGroupBox>
+#include <QEvent>
+#include <QDebug>
+#include <QSpacerItem>
+#define  EDIT_SVG_PATH  ":/image/editor.svg"
 #define  COPY_SVG_PATH  ":/image/copy.svg"
 #define  REMOVE_SVG_PATH  ":/image/delete.svg"
-#define  SEARCH_SVG_CLEAN ":/image/hover.svg"
+#define  SEARCH_SVG_CLEAN ":/image/button-close-hover-click-two.svg"
+#define  SEARCH_SVG_CLEAN_BACK ":/image/button-close-hover-click-add-background-one.svg"
 class ClipboardWidgetEntry : public QWidget
 {
 public:
@@ -37,6 +44,10 @@ public:
     QPushButton *m_pRemoveButton;
     QLabel      *m_pCopyDataLabal;
     QHBoxLayout *m_pHLayout;
+
+protected:
+    void enterEvent(QEvent *);                      //进入QWidget瞬间事件
+    void leaveEvent(QEvent *);                      //离开QWidget瞬间事件
 };
 
 #endif // CLIPBOARDWIDGETENTRY_H
