@@ -26,16 +26,21 @@
 #include <QLineEdit>
 #include <QHBoxLayout>
 #include <QAction>
+#include <QWidgetAction>
 #include "clipboardwidgetentry.h"
+#define  SIDEBAR_SEARCH_QSS_PATH  ":/qss/sideBarSearchArea.css"
 class SearchWidgetItemContent:public QWidget
 {
     Q_OBJECT
 public:
     SearchWidgetItemContent(QWidget *parent = nullptr);
-    QPushButton *m_pClearTextEdit;
+    QPushButton *m_pClearTextButton;
     QPushButton *m_pClearListWidgetButton;
     QLineEdit   *m_pLineEditArea;
     QHBoxLayout *m_pHBoxLayout;
+
+private slots:
+    void textChageSlots(const QString &text);
 };
 
 #endif // SEARCHWIDGETITEMCONTENT_H
