@@ -22,35 +22,63 @@
 #include <QApplication>
 #include <QMimeData>
 #include <QFile>
+#include <QTranslator>
+ClipboardSignal *globalClipboardSignal;
 SidebarClipboardPlugin::SidebarClipboardPlugin(QObject *parent)
 {
     Q_UNUSED(parent);
-    m_pSidebarClipboardBox = new QGroupBox(tr("  剪贴板"));
-    m_pSidebarClipboardBox->setObjectName("ClipboardBox");
+    translator = new QTranslator;
+    QLocale locale;
+    //获取系统语言环境
+    if ( locale.language() == QLocale::Chinese ) {
+        qDebug() << "中文环境" ;
+        translator->load(QString(":/translations/test_zh_CN.qm"));  //选择翻译文件
+        QApplication::installTranslator(translator);
+    }
+    installEventFilter(this);
+    m_pSidebarClipboardWidget = new QWidget();
+    m_pSidebarClipboardWidget->setObjectName("ClipboardWidget");
+    m_pSidebarClipboardWidget->setContentsMargins(0,0,0,0);
+
     m_pClipboardLaout = new QVBoxLayout;
-    m_pShortcutOperationListWidget = new QListWidget;
+    m_pClipboardLaout->setContentsMargins(0,0,0,0);
+
+    m_pShortcutOperationListWidget = new ClipBoardLisetWidget;
+    m_pSearchWidgetListWidget      = new QListWidget;
+
+    m_pSideBarClipboardLable = new QLabel(tr("No clip content"));
+
+    connect(this, &SidebarClipboardPlugin::Itemchange, this, &SidebarClipboardPlugin::ItemNumchagedSlots);
+
+    m_pSearchWidgetListWidget->setFixedSize(400, 42);
+    m_pShortcutOperationListWidget->setContentsMargins(0,0,0,0);
+    m_pSearchWidgetListWidget->setContentsMargins(0,0,0,0);
+
     createFindClipboardWidgetItem();
+
+    m_pClipboardLaout->addWidget(m_pSearchWidgetListWidget);
     m_pClipboardLaout->addWidget(m_pShortcutOperationListWidget);
-    m_pSidebarClipboardBox->setLayout(m_pClipboardLaout);
+    m_pClipboardLaout->addWidget(m_pSideBarClipboardLable);
+
+    m_pSidebarClipboardWidget->setLayout(m_pClipboardLaout);
+    m_pShortcutOperationListWidget->setVisible(false);
+
     m_pShortcutOperationListWidget->setObjectName("ShortcutOperationList");
-    m_pSidebarClipboardBox->setObjectName("ClipboardBox");
+    m_pSearchWidgetListWidget->setObjectName("SearchWidgetListWidget");
+    m_pSideBarClipboardLable->setObjectName("SideBarClipboardLable");
+
     m_pSidebarClipboard = QApplication::clipboard();
-    m_pEditWidget = nullptr;
     connect(m_pSidebarClipboard, &QClipboard::dataChanged, this, [=]() {
        const QMimeData *mimeData = new QMimeData();
        mimeData = m_pSidebarClipboard->mimeData();
-       qDebug() << "文本的format" << m_pSidebarClipboard->mimeData()->formats();
        createWidgetEntry(mimeData);
     });
 
-    qDebug() << "after connect, this =" << this;
     /* 加载样式表 */
     QFile file(SIDEBAR_CLIPBOARD_QSS_PATH);
     if (file.open(QFile::ReadOnly)) {
         QString strQss = QLatin1String(file.readAll());
-        QString strPaletteColor = strQss.mid(20, 7);
-        m_pSidebarClipboardBox->setPalette(QPalette(QColor(strPaletteColor)));
-        m_pSidebarClipboardBox->setStyleSheet(strQss);
+        m_pSidebarClipboardWidget->setStyleSheet(strQss);
         file.close();
     }
 }
@@ -60,7 +88,7 @@ QMimeData * SidebarClipboardPlugin::copyMinedata(const QMimeData* mimeReference)
 {
     QMimeData *mimecopy = new QMimeData();
     foreach (QString format, mimeReference->formats()) {
-//        qDebug() << "剪贴板数据的格式" << format;
+
         QByteArray data = mimeReference->data(format);
 //        if (format.startsWith("x-special/ukui-copied-files")) {
 //            int indexBegin = format.indexOf('""') + 1;
@@ -68,7 +96,9 @@ QMimeData * SidebarClipboardPlugin::copyMinedata(const QMimeData* mimeReference)
 //            format = format.mid(indexBegin, indexEnd - indexBegin);
 //        }
         mimecopy->setData(format, data);
+//        qDebug() << "剪贴板数据的格式" << format;
     }
+
     return mimecopy;
 }
 
@@ -82,20 +112,21 @@ QListWidget* SidebarClipboardPlugin::getClipbaordListWidget()
     }
 }
 
-/* 创建与侧边栏主app通信类，暂时废弃 */
+/* 创建与侧边栏主app通信类 */
 SidebarClipBoardSignal* SidebarClipboardPlugin :: createClipSignal()
 {
     m_pClipSignal = new ClipboardSignal;
+    globalClipboardSignal = m_pClipSignal;
     return m_pClipSignal;
 }
 
 /* 侧边栏接口，将整个剪贴板界面set进入侧边栏 */
-QGroupBox* SidebarClipboardPlugin::getClipbaordGroupBox()
+QWidget* SidebarClipboardPlugin::getClipbaordGroupBox()
 {
-    if (m_pSidebarClipboardBox == nullptr) {
+    if (m_pSidebarClipboardWidget == nullptr) {
         return nullptr;
     } else {
-        return m_pSidebarClipboardBox;
+        return m_pSidebarClipboardWidget;
     }
 }
 
@@ -105,11 +136,12 @@ void SidebarClipboardPlugin::createFindClipboardWidgetItem()
     QListWidgetItem *pListWidgetItem = new QListWidgetItem;
     pListWidgetItem->setFlags(Qt::NoItemFlags);
     m_pSearchArea = new SearchWidgetItemContent;
+
     connect(m_pSearchArea->m_pClearListWidgetButton, &QPushButton::clicked, this, &SidebarClipboardPlugin::removeAllWidgetItem);
     connect(m_pSearchArea->m_pLineEditArea, SIGNAL(textChanged(QString)), this, SLOT(searchClipboardLableTextSlots(QString)));
-    pListWidgetItem->setSizeHint(QSize(350,40));
-    m_pShortcutOperationListWidget->insertItem(0,pListWidgetItem);
-    m_pShortcutOperationListWidget->setItemWidget(pListWidgetItem, m_pSearchArea);
+    pListWidgetItem->setSizeHint(QSize(400,38));
+    m_pSearchWidgetListWidget->insertItem(0,pListWidgetItem);
+    m_pSearchWidgetListWidget->setItemWidget(pListWidgetItem, m_pSearchArea);
 }
 
 /*创建Widgetitem条目*/
@@ -122,6 +154,7 @@ void SidebarClipboardPlugin::createWidgetEntry(const QMimeData *mimeData)
     QString text;
     QListWidgetItem *pListWidgetItem = new QListWidgetItem;
     ClipboardWidgetEntry *w = new ClipboardWidgetEntry;
+    w->setFixedSize(397, 42);
     if (nullptr == mimeData->urls().value(0).toString()) {
         text = mimeData->text();
         qDebug() << "text文本数据为:" << text;
@@ -142,23 +175,54 @@ void SidebarClipboardPlugin::createWidgetEntry(const QMimeData *mimeData)
         return ;
     }
 
-    //当有重复的时候将会置顶
+    /* 当有重复的时候将会置顶 */
     if(booleanExistWidgetItem(text)) {
         qDebug() << "此条内容已存在，就是当前置顶的条数";
         delete pListWidgetItem;
         delete w;
         return;
     }
-    registerMimeData(w, copyMinedata(mimeData));  //hash插入QMimeData，保留原数据
+    /* hash插入QMimeData，保留原数据 */
+    registerMimeData(w, copyMinedata(mimeData));
+    registerLabelText(w, text);
 
     /* 当超过一定数目的WidgetItem数目时，删除最后一条消息 */
     if (m_pShortcutOperationListWidget->count() >= WIDGET_ENTRY_COUNT) {
         removeLastWidgetItem();
     }
 
-    pListWidgetItem->setSizeHint(QSize(350,50));
+    pListWidgetItem->setSizeHint(QSize(397,42));
     pListWidgetItem->setFlags(Qt::NoItemFlags);
-    w->m_pCopyDataLabal->setText(text);
+    //设置...字样
+    QFontMetrics fontMetrics(w->m_pCopyDataLabal->font());
+    int fontSize = fontMetrics.width(text);
+    QString formatBody = text;
+    if(fontSize > (200 - 70))
+    {
+        QStringList list = formatBody.split("\n");
+        if (list.size() >= 2) {
+            //当有几行时，只需要截取第一行就行，在第一行后面加...
+            formatBody = list.at(0);
+            int oneFontSize = fontMetrics.width(formatBody);
+            if (oneFontSize > (200 - 50)) {
+                formatBody = fontMetrics.elidedText(formatBody, Qt::ElideRight, 200 - 50);
+            }
+            formatBody = fontMetrics.elidedText(formatBody, Qt::ElideRight, oneFontSize - 1);
+        } else {
+            //说明只存在一行，在最后面加...就行
+            formatBody = fontMetrics.elidedText(formatBody, Qt::ElideRight, 200 - 50);
+        }
+    } else {
+        QStringList list = formatBody.split("\n");
+        if (list.size() >= 2) {
+            formatBody = list.at(0);
+            qDebug() << "第一端" << formatBody;
+            int oneFontSize = fontMetrics.width(formatBody);
+            formatBody = fontMetrics.elidedText(formatBody, Qt::ElideRight, oneFontSize - 1);
+        }
+    }
+    w->m_pCopyDataLabal->setText(formatBody);
+
     connect(w->m_pPopButton, &QPushButton::clicked, this, [=](){
         this->popButtonSlots(w);
     });
@@ -171,9 +235,10 @@ void SidebarClipboardPlugin::createWidgetEntry(const QMimeData *mimeData)
         this->removeButtonSlots(w);
     });
 
-    m_pShortcutOperationListWidget->insertItem(1,pListWidgetItem);
+    m_pShortcutOperationListWidget->insertItem(0, pListWidgetItem);
     m_pShortcutOperationListWidget->setItemWidget(pListWidgetItem, w);
     registerWidgetItem(w, pListWidgetItem);
+    emit Itemchange();
 }
 
 /* 注册WidgetItem条目与widgetItem的键值对关系 */
@@ -212,6 +277,18 @@ void SidebarClipboardPlugin::removeWidgetItem(ClipboardWidgetEntry *key)
     return;
 }
 
+//移除所有的widgetItem的值
+void SidebarClipboardPlugin::removeHashAllWidgetItem()
+{
+    QHash<ClipboardWidgetEntry*, QListWidgetItem*>::const_iterator iter1 = m_pclipboardEntryItem.constBegin(); //遍历hash，方法1
+    QHash<ClipboardWidgetEntry*, QListWidgetItem*>::const_iterator delIndex = iter1;
+    while ((delIndex = iter1) != m_pclipboardEntryItem.constEnd()) {
+        ++iter1;
+        m_pclipboardEntryItem.remove(delIndex.key());
+    }
+    return;
+}
+
 /* 注册Mindata数据类型，保存到hash表中 */
 void SidebarClipboardPlugin::registerMimeData(ClipboardWidgetEntry *key, const QMimeData *value)
 {
@@ -248,6 +325,72 @@ void SidebarClipboardPlugin::removeMimeData(ClipboardWidgetEntry *key)
     return;
 }
 
+//移除所有的Mindata数据类型
+void SidebarClipboardPlugin::removeHashAllMimeData()
+{
+    QHash<ClipboardWidgetEntry*, const QMimeData*>::const_iterator iter1 = m_pclipbordMimeData.constBegin(); //遍历hash，方法1
+    QHash<ClipboardWidgetEntry*, const QMimeData*>::const_iterator delIndex = iter1;
+    while ((delIndex = iter1) != m_pclipbordMimeData.constEnd()) {
+        const QMimeData* userInfo = (const QMimeData*)delIndex.value();
+        if (userInfo != NULL)
+        {
+            delete userInfo;
+            userInfo = NULL;
+        }
+        ++iter1;
+        m_pclipbordMimeData.remove(delIndex.key());
+    }
+    return;
+}
+
+//注册条目中的lable与条目中的原始字符串文本相对应关系
+void SidebarClipboardPlugin::registerLabelText(ClipboardWidgetEntry*key, QString value)
+{
+    if (nullptr == key || nullptr == value) {
+        qWarning() << "QLabel *key," << key << "QString *value值有问题"  << value;
+        return;
+    }
+    if (m_pLabelText.value(key) != nullptr) {
+        qWarning() << "注册：value已存在";
+        return;
+    }
+    m_pLabelText.insert(key, value);
+    return;
+}
+
+//获取Label中的原始文本
+QString SidebarClipboardPlugin::getLabelText(ClipboardWidgetEntry *key)
+{
+    if (key == nullptr) {
+        qWarning() << "QLabel *key为空" << key;
+        return nullptr;
+    }
+    return m_pLabelText.value(key);
+}
+
+//删除label中保存在hash表中的原始文本
+void SidebarClipboardPlugin::removeLabelText(ClipboardWidgetEntry *key)
+{
+    if (nullptr == key) {
+        qWarning() << "删除：QLabel *key 为空";
+        return;
+    }
+    m_pLabelText.remove(key);
+    return;
+}
+
+//移除lable hash表中所有键值对
+void SidebarClipboardPlugin::removeHashAllLabelText()
+{
+    QHash<ClipboardWidgetEntry*, QString>::const_iterator iter1 = m_pLabelText.constBegin(); //遍历hash，方法1
+    QHash<ClipboardWidgetEntry*, QString>::const_iterator delIndex = iter1;
+    while ((delIndex = iter1) != m_pLabelText.constEnd()) {
+        ++iter1;
+        m_pLabelText.remove(delIndex.key());
+    }
+    return;
+}
+
 /* 将新置顶widget写入到剪贴板中去 */
 void SidebarClipboardPlugin::WhetherTopFirst()
 {
@@ -256,7 +399,7 @@ void SidebarClipboardPlugin::WhetherTopFirst()
     //当删除为第一项时，则自动将第二项置顶
     int count = m_pShortcutOperationListWidget->count();
     qDebug() << "当前还剩多少条目" << count;
-    QListWidgetItem *PopWidgetItem =  m_pShortcutOperationListWidget->item(1);
+    QListWidgetItem *PopWidgetItem =  m_pShortcutOperationListWidget->item(0);
     qDebug() << "QListWidgetItem *PopWidgetItem" << PopWidgetItem;
     if (PopWidgetItem == nullptr) {
         qWarning() << "从剪贴板获取的PopWidgetItem指针为空";
@@ -293,8 +436,13 @@ void SidebarClipboardPlugin::popButtonSlots(ClipboardWidgetEntry *w)
     QListWidgetItem *p = getWidgetItem(w); //获取Item
     removeWidgetItem(w); //移除hash表中保存的Widget和Item键值对
     removeMimeData(w);
-    m_pShortcutOperationListWidget->takeItem(m_pShortcutOperationListWidget->row(p)); //删除Item;
-    w->deleteLater(); //释放掉ClipboardWidgetEntry;
+    removeLabelText(w);
+
+    delete w;
+    w = nullptr;
+    QListWidgetItem *Item = m_pShortcutOperationListWidget->takeItem(m_pShortcutOperationListWidget->row(p)); //删除Item;
+    delete Item;
+
     m_pSidebarClipboard->setMimeData((QMimeData*)pMimeData, QClipboard::Clipboard);
     m_pSidebarClipboard->setMimeData((QMimeData*)pMimeData, QClipboard::Selection);
     return;
@@ -312,65 +460,88 @@ void SidebarClipboardPlugin::removeButtonSlots(ClipboardWidgetEntry *w)
     qDebug() << "在删除中行数removeButtonSlots:" << tmp;
     removeWidgetItem(w); //移除hash表中保存的Widget和Item键值对
     removeMimeData(w);
-    m_pShortcutOperationListWidget->takeItem(tmp); //删除Item;
-//    delete p;
-    w->deleteLater(); //释放掉ClipboardWidgetEntry;
-
+    removeLabelText(w);
+    delete w; //释放掉ClipboardWidgetEntry;
+    w = nullptr;
+    QListWidgetItem *item =  m_pShortcutOperationListWidget->takeItem(tmp); //删除Item;
+    delete item;
     /* 判断当前删除的是不是第一个条目 */
-    if (1 == tmp) {
+    if (0 == tmp) {
         qDebug() << "删除当前的条目为第一个条目";
         /* 将新的第一个条目中的内容重新写到剪贴板中去 */
         WhetherTopFirst();
-        return;
     }
+    emit Itemchange();
     return;
 }
 
 /* 编辑槽函数 */
 void SidebarClipboardPlugin::editButtonSlots(ClipboardWidgetEntry *w)
 {
-    if (m_pEditWidget != nullptr) {
-        qInfo() << "编辑界面已存在，不需要再创建";
+    qDebug() << "ClipboardWidgetEntry:::" << w;
+    /* 防止重复创建 */
+
+    if (w == nullptr) {
+        qDebug() << "传入值为空";
         return;
     }
-
+    EditorWidget EditWidget;
     /* 获取保存在hash表中的数据，改变之前保存的数据 */
     QMimeData* pMimeData = (QMimeData*)getMimeData(w);
     if (nullptr == pMimeData) {
         qDebug() << "剪贴板元数据不存在";
         return;
     }
-
     QListWidgetItem* p_wItem = (QListWidgetItem*)getWidgetItem(w);
-    m_pEditWidget = new EditorWidget;
-    QString text = w->m_pCopyDataLabal->text();
-    m_pEditWidget->m_pEditingArea->setText(text);
-    m_pEditWidget->show();
-
-    connect(m_pEditWidget->m_pConfirmButton, &QPushButton::clicked, this, [=](){
-        if (w == nullptr) {
-            qWarning() << "ClipboardWidgetEntry为空，已被清除";
-            return ;
+    QString text = getLabelText(w);
+    EditWidget.m_pEditingArea->setText(text);
+    int nRet = EditWidget.exec();
+    if (nRet == QDialog::Accepted) {
+        QFontMetrics fontMetrics(w->m_pCopyDataLabal->font());
+        int fontSize = fontMetrics.width(text);
+        QString formatBody = EditWidget.m_pEditingArea->toPlainText();
+        if(fontSize > (200 - 70)) {
+            QStringList list = formatBody.split("\n");
+            if (list.size() >= 2) {
+                //当有几行时，只需要截取第一行就行，在第一行后面加...
+                formatBody = list.at(0);
+                int oneFontSize = fontMetrics.width(formatBody);
+                if (oneFontSize > (200 - 50)) {
+                    formatBody = fontMetrics.elidedText(formatBody, Qt::ElideRight, 200-50);
+                }
+                formatBody = fontMetrics.elidedText(formatBody, Qt::ElideRight, oneFontSize - 1);
+            } else {
+                //说明只存在一行，在最后面加...就行
+                formatBody = fontMetrics.elidedText(formatBody, Qt::ElideRight, 200 - 50);
+            }
+        } else {
+            QStringList list = formatBody.split("\n");
+            if (list.size() >= 2) {
+                formatBody = list.at(0);
+                int oneFontSize = fontMetrics.width(formatBody);
+                formatBody = fontMetrics.elidedText(formatBody, Qt::ElideRight, oneFontSize - 1);
+            }
         }
+        w->m_pCopyDataLabal->setText(formatBody);
+        pMimeData->setText(EditWidget.m_pEditingArea->toPlainText());
 
-        w->m_pCopyDataLabal->setText(m_pEditWidget->m_pEditingArea->toPlainText());
-        pMimeData->setText(m_pEditWidget->m_pEditingArea->toPlainText());
+        if (EditWidget.m_pEditingArea->toPlainText() != text) {
+            //当编辑后数据改变时，就需要将m_pLabelText中的value改变
+            removeLabelText(w);
+            registerLabelText(w, EditWidget.m_pEditingArea->toPlainText());
+        }
 
         //获取当前条目所在位置，是不是在第一
         int row_num = m_pShortcutOperationListWidget->row(p_wItem);
-        if (row_num == 1) {
-            m_pSidebarClipboard->setMimeData((QMimeData*)pMimeData, QClipboard::Clipboard);
-            m_pSidebarClipboard->setMimeData((QMimeData*)pMimeData, QClipboard::Selection);
+        if (row_num == 0) {
+            popButtonSlots(w);
         }
         qDebug() << "d当前所在的条木" << row_num;
-        m_pEditWidget->deleteLater();
-        m_pEditWidget = nullptr;
-    });
-
-    connect(m_pEditWidget->m_pCancelButton, &QPushButton::clicked, this, [=](){
-        m_pEditWidget->deleteLater();
-        m_pEditWidget = nullptr;
-    });
+    }
+    else if (nRet == QDialog::Rejected)
+    {
+        qDebug() << "不需要做其余操作";
+    }
 }
 
 /* 当超过限制条数时删除最后一条消息 */
@@ -378,23 +549,25 @@ void SidebarClipboardPlugin::removeLastWidgetItem()
 {
     ClipboardWidgetEntry *w = (ClipboardWidgetEntry*)m_pShortcutOperationListWidget->itemWidget(m_pShortcutOperationListWidget->item(m_pShortcutOperationListWidget->count()-1));
     qDebug() << "当前条目数目" << m_pShortcutOperationListWidget->count();
-    //m_pShortcutOperationListWidget->takeItem(m_pShortcutOperationListWidget->count()-1);
-    delete m_pShortcutOperationListWidget->item(m_pShortcutOperationListWidget->count()-1);
+
     removeWidgetItem(w);
     removeMimeData(w);
-    qDebug() << "当前条目数目sadasdsad" << m_pShortcutOperationListWidget->count();
-    w->deleteLater();
+    removeLabelText(w);
+    delete w;
+    w = nullptr;
+    QListWidgetItem *tmp = m_pShortcutOperationListWidget->takeItem(m_pShortcutOperationListWidget->count()-1);
+    delete tmp;
 }
 
 /* 判断在ListWidget是否存在，如果不存在则返回fasle，创建，返回true，不创建 */
 bool SidebarClipboardPlugin::booleanExistWidgetItem(QString Text)
 {
     int tmp = m_pShortcutOperationListWidget->count();
-    for(int i = 1; i < tmp; i++) {
+    for (int i = 0; i < tmp; i++) {
         ClipboardWidgetEntry *w = (ClipboardWidgetEntry*)m_pShortcutOperationListWidget->itemWidget(m_pShortcutOperationListWidget->item(i));
-        QString WidgetText = w->m_pCopyDataLabal->text();
+        QString WidgetText = getLabelText(w);
         if (WidgetText == Text) {
-            if(i == 1) {
+            if(i == 0) {
                 qDebug() << "当前的数据就是置顶数据";
                 return true;
             }
@@ -409,40 +582,51 @@ bool SidebarClipboardPlugin::booleanExistWidgetItem(QString Text)
 void SidebarClipboardPlugin::removeAllWidgetItem()
 {
     int tmp = m_pShortcutOperationListWidget->count();
-    for(int i = 1; i < tmp; i++) {
-        ClipboardWidgetEntry *w = (ClipboardWidgetEntry*)m_pShortcutOperationListWidget->itemWidget(m_pShortcutOperationListWidget->item(1));
-        m_pShortcutOperationListWidget->takeItem(1);
-        delete m_pShortcutOperationListWidget->item(1);
+    qDebug() << "m_pShortcutOperationListWidget->count()" << tmp;
+    for (int i = 0; i < tmp; i++) {
+        ClipboardWidgetEntry *w = (ClipboardWidgetEntry*)m_pShortcutOperationListWidget->itemWidget(m_pShortcutOperationListWidget->item(0));
+        qDebug() << "w-->  " << w;
         removeWidgetItem(w);
-        w->deleteLater();
-    }
-    if (m_pEditWidget == nullptr) {
-        return ;
-    } else {
-        m_pEditWidget->deleteLater();
-        m_pEditWidget = nullptr;
+        removeMimeData(w);
+        removeLabelText(w);
+        delete w;
+        QListWidgetItem *tmp = m_pShortcutOperationListWidget->takeItem(0);
+        delete tmp;
     }
+    emit Itemchange();
 }
 
 /* 搜索 槽函数 */
 void SidebarClipboardPlugin::searchClipboardLableTextSlots(QString Text)
 {
+    if (Text == "") {
+        return;
+    }
     qDebug() << "Text" << Text;
-    int row=1;
-    QString line;
-    while(row<(m_pShortcutOperationListWidget->count()))
-    {
-        ClipboardWidgetEntry *w = (ClipboardWidgetEntry*)m_pShortcutOperationListWidget->itemWidget(m_pShortcutOperationListWidget->item(row));
-        line=w->m_pCopyDataLabal->text();
-        if (line.contains(Text, Qt::CaseSensitive)) {
-            popButtonSlots(w);
-            w->show();
-            //w->hide();
+    QHash<ClipboardWidgetEntry*, QString>::const_iterator iter1 = m_pLabelText.constBegin();
+    while (iter1 != m_pLabelText.constEnd()) {
+        if (iter1.value().contains(Text, Qt::CaseSensitive)) {
+            ClipboardWidgetEntry *p = iter1.key();
+            ++iter1;
+            popButtonSlots(p);
         } else {
-            w->hide();
+//            iter1.key()->hide();
+            ++iter1;
         }
-        row++;
     }
     return;
 }
 
+/* Item数目发生变化 */
+void SidebarClipboardPlugin::ItemNumchagedSlots()
+{
+    int num = m_pShortcutOperationListWidget->count();
+    qDebug() << "Item数目发生变化， 当前Item数目" << num;
+    if (num > 0) {
+        m_pSideBarClipboardLable->setVisible(false);
+        m_pShortcutOperationListWidget->setVisible(true);
+    } else {
+        m_pSideBarClipboardLable->setVisible(true);
+        m_pShortcutOperationListWidget->setVisible(false);
+    }
+}
