@@ -18,7 +18,6 @@
 
 #include "takeinboxtoolbutton.h"
 #include <QToolTip>
-#include <QHelpEvent>
 
 TakeInBoxToolButton::TakeInBoxToolButton()
 {
@@ -27,16 +26,18 @@ TakeInBoxToolButton::TakeInBoxToolButton()
 
 void TakeInBoxToolButton::enterEvent(QEvent *event)
 {
-    QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
+    Q_UNUSED(event);
+
+    //设置边框, 边框色, 背景色, 字体色, 字号
+    setStyleSheet("QToolTip{border:1px solid rgba(255, 255, 255, 0.2); background-color: #1A1A1A; color:#FFFFFF; padding:4px; border-radius:6px; font-size:12px;}");
+
     if(false == m_bEnterTakeInBox)
     {
-        QToolTip::showText(QPoint(helpEvent->pos().x(), (helpEvent->pos().y() + 30)), "进入收纳盒");
-//        QToolTip::showText(helpEvent->globalPos(), "进入收纳盒");
+        this->setToolTip(QString::fromLocal8Bit("进入收纳盒"));
     }
     else
     {
-        QToolTip::showText(QPoint(helpEvent->pos().x(), (helpEvent->pos().y() + 30)), "退出收纳盒");
-//        QToolTip::showText(helpEvent->globalPos(), "退出收纳盒");
+        this->setToolTip(QString::fromLocal8Bit("退出收纳盒"));
     }
     return;
 }
@@ -44,6 +45,5 @@ void TakeInBoxToolButton::enterEvent(QEvent *event)
 void TakeInBoxToolButton::leaveEvent(QEvent *event)
 {
     Q_UNUSED(event);
-    QToolTip::hideText();
     return;
 }
