@@ -26,19 +26,16 @@ class TakeInBoxToolButton : public QToolButton
 {
     Q_OBJECT
 public:
-    explicit TakeInBoxToolButton();
-    void setEnterFlags(bool bFlags) {m_bEnterTakeInBox = bFlags;}
+    explicit        TakeInBoxToolButton();
+    void            setEnterFlags(bool bFlags) {m_bEnterTakeInBox = bFlags;}
 
 protected:
-    virtual void enterEvent(QEvent *event) override;
-    virtual void leaveEvent(QEvent *event) override;
+    virtual void    enterEvent(QEvent *event) override;
+    virtual void    leaveEvent(QEvent *event) override;
 
 private:
-    bool        m_bEnterTakeInBox;
+    bool            m_bEnterTakeInBox;
 
-signals:
-
-public slots:
 };
 
 #endif // TAKEINBOXTOOLBUTTON_H
